@@ -5,6 +5,7 @@
 */
 #include "identitytreedelegate.h"
 #include "identitytreemodel.h"
+#include <KLineEditEventHandler>
 #include <QLineEdit>
 using namespace KIdentityManagementWidgets;
 IdentityTreeDelegate::IdentityTreeDelegate(QObject *parent)
@@ -19,6 +20,7 @@ QWidget *IdentityTreeDelegate::createEditor(QWidget *parent, const QStyleOptionV
     Q_UNUSED(index);
     Q_UNUSED(option);
     auto *lineEdit = new QLineEdit(parent);
+    KLineEditEventHandler::catchReturnKey(lineEdit);
     auto *that = const_cast<IdentityTreeDelegate *>(this);
     connect(lineEdit, &QLineEdit::editingFinished, this, [this, that]() {
         Q_EMIT that->commitData(mLineEdit);
@@ -30,13 +32,13 @@ QWidget *IdentityTreeDelegate::createEditor(QWidget *parent, const QStyleOptionV
 
 void IdentityTreeDelegate::setEditorData(QWidget *editor, const QModelIndex &index) const
 {
-    auto identityNameIndex = index.model()->index(index.row(), KIdentityManagementCore::IdentityTreeModel::DisplayIdentityNameRole);
+    auto identityNameIndex = index.model()->index(index.row(), KIdentityManagementCore::IdentityTreeModel::IdentityNameRole);
     qobject_cast<QLineEdit *>(editor)->setText(identityNameIndex.data().toString());
 }
 
 void IdentityTreeDelegate::setModelData(QWidget *editor, QAbstractItemModel *model, const QModelIndex &index) const
 {
-    auto identityNameIndex = index.model()->index(index.row(), KIdentityManagementCore::IdentityTreeModel::DisplayIdentityNameRole);
+    auto identityNameIndex = index.model()->index(index.row(), KIdentityManagementCore::IdentityTreeModel::IdentityNameRole);
     model->setData(identityNameIndex, qobject_cast<QLineEdit *>(editor)->text());
 }
 
